@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 my %introduces = ( 5.024 => [qw[
                                  unicode8.0 \b{lb} sprintf-reorder
@@ -103,7 +103,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =head1 SYNOPSIS
 
@@ -438,15 +438,15 @@ L<perl5220delta/Incompatible Changes>.
 
 =head3 unicode8.0
 
-L<perldelta#Unicode 8.0 is now supported>.
+L<perldelta/Unicode 8.0 is now supported>.
 
 =head3 \b{lb}
 
-L<perldelta#New \b{lb} boundary in regular expressions>.
+L<perldelta/New \b{lb} boundary in regular expressions>.
 
 =head3 sprintf-reorder
 
-L<perldelta#printf and sprintf now allow reordered precision arguments>.
+L<perldelta/printf and sprintf now allow reordered precision arguments>.
 
 
 =head1 AUTHOR
